import { Filter, Data, FilterRelations } from '@sisense/sdk-data';
import type { NlqResponseData } from '../../ai';
import { NlqChartWidgetStyleOptions } from '../../types';
/**
 * Props for {@link NlqChartWidget} component.
 *
 * @group Generative AI
 * @internal
 */
export interface NlqChartWidgetProps {
    /**
     * Chatbot NLQ Response
     */
    nlqResponse: NlqResponseData;
    /**
     * The dashboard filters to be applied to the chart
     */
    filters?: Filter[] | FilterRelations;
    /**
     * A callback that allows to modify data immediately after it has been retrieved.
     * Can be used to inject modification of queried data.
     */
    onDataReady?: (data: Data) => Data;
    /**
     * Boolean flag to show or hide the widget header
     *
     * Note: set to 'false' to hide the widget header
     *
     * @default true
     */
    styleOptions?: NlqChartWidgetStyleOptions;
}
/**
 * React component that renders a chart widget based on NLQ response data.
 *
 * @example
 * ```tsx
 * import { NlqChartWidget, NlqResponseData } from '@sisense/sdk-ui/ai';
 * import { Filter } from '@sisense/sdk-data';
 *
 * function ExampleComponent(nlqResponse: NlqResponseData, filters?: Filter[]) {
 *
 *    return (
 *      <ChartWidgetWithInsights
 *        nlqResponse={nlqResponse}
 *        filters={filters}
 *      />
 *    );
 * }
 * ```
 * @param props - {@link NlqChartWidgetProps}
 * @group Generative AI
 * @internal
 */
export declare const NlqChartWidget: ({ nlqResponse, onDataReady, styleOptions, filters, }: NlqChartWidgetProps) => import("react/jsx-runtime").JSX.Element;
