/// <reference types="react" />
import { UseGetNlgInsightsParams } from './use-get-nlg-insights';
/**
 * Props for {@link GetNlgInsights} component.
 */
export interface GetNlgInsightsProps extends Omit<UseGetNlgInsightsParams, 'enabled'> {
}
/**
 * React component that fetches and displays a collapsible analysis of the provided query using natural language generation (NLG).
 * Specifying a query is similar to providing parameters to a {@link useExecuteQuery} hook, using dimensions, measures, and filters.
 *
 * @example
 * ```tsx
 * <GetNlgInsights
 *   dataSource="Sample ECommerce"
 *   dimensions={[DM.Commerce.Date.Years]}
 *   measures={[measureFactory.sum(DM.Commerce.Revenue)]}
 * />
 * ```
 * @param props - {@link GetNlgInsightsProps}
 * @returns Collapsible container wrapping a text summary
 * @group Generative AI
 */
declare const _default: import("react").FunctionComponent<GetNlgInsightsProps>;
export default _default;
