import { ChartDataOptions, ChartType, ChartStyleOptions } from '../../../types';
import { MetadataItem } from '@sisense/sdk-data';
import { AxesMapping, ChartRecommendations, ExpandedQueryModel } from '../../../analytics-composer/types';
/**
 * @internal
 */
export declare const getChartRecommendationsOrDefault: (response: ExpandedQueryModel) => ChartRecommendations;
/**
 * Maps the metadata items to the chart data options.
 *
 * @param metadataItems - metadata items
 * @param chartFamily - chart family
 * @param axesMapping - axes mapping
 * @returns chart data options
 * @internal
 */
export declare const getChartDataOptions: (metadataItems: MetadataItem[], chartFamily: string, axesMapping: AxesMapping) => ChartDataOptions;
/**
 * Get chart style options for the chart widget.
 *
 * @param chartType - chart type
 * @param axesMapping - axes mapping
 * @param initialStyleOptions - initial style options
 * @param useCustomizedStyleOptions - whether to use customized style. Charts as inline response messages use customized style. Charts for Query Composer use default style.
 * @returns chart style options
 * @internal
 */
export declare const getChartStyleOptions: (chartType: ChartType, axesMapping: AxesMapping, initialStyleOptions: ChartStyleOptions, useCustomizedStyleOptions: boolean) => ChartStyleOptions;
/**
 * Get chart options for the chart widget.
 *
 * @param jaql - metadata items
 * @param chartRecommendations - chart recommendations
 * @param useCustomizedStyleOptions - whether to use customized style. Charts as inline response messages use customized style. Charts for Query Composer use default style.
 * @internal
 */
export declare const getChartOptions: (jaql: MetadataItem[], chartRecommendations: ChartRecommendations, useCustomizedStyleOptions?: boolean) => {
    dataOptions: ChartDataOptions;
    chartStyleOptions: ChartStyleOptions;
};
