import { HttpClient } from '@sisense/sdk-rest-client';
import { AppConfig, ThemeSettings } from '../../types';
import { FeatureMap } from './types/features.js';
/**
 * Application settings
 */
export type AppSettings = Required<ConfigurableAppSettings> & ServerSettings;
/**
 * Application settings that can be overridden by the user
 */
type ConfigurableAppSettings = AppConfig;
/**
 * Fusion platform settings
 */
type ServerSettings = {
    serverThemeSettings: ThemeSettings;
    serverLanguage: string;
    serverVersion: string;
    serverFeatures: FeatureMap;
    user: {
        tenant: {
            name: string;
        };
    };
};
/**
 * Gets the application settings
 *
 * @param customConfig - Custom application configuration
 * @param httpClient - Sisense REST API client
 * @param isWat - Whether the application is running with WAT authentication
 * @returns - Application settings
 */
export declare function getSettings(customConfig: ConfigurableAppSettings, httpClient: Pick<HttpClient, 'get' | 'url'>, useDefaultPalette?: boolean): Promise<AppSettings>;
export {};
