import { Attribute, Measure, Filter, QueryResultData, DataSource, FilterRelationsJaql } from '@sisense/sdk-data';
import { ClientApplication } from './app/client-application.js';
import { executeQuery as executeQueryFunction } from './query/execute-query.js';
import { BoxplotChartCustomDataOptions, BoxplotChartDataOptionsInternal } from './chart-data-options/types.js';
/**
 * Processes box whisker data and outliers data to combine them into a single data set.
 *
 * @param {QueryResultData} boxWhiskerData - The data for the box whisker.
 * @param {QueryResultData} outliersData - The data for the outliers.
 * @param {BoxplotChartDataOptionsInternal} [dataOptions] - Optional data options for customizing data processing.
 * @returns {QueryResultData} The combined data with outliers included in the box whisker plot.
 */
export declare const boxWhiskerProcessResultInternal: (boxWhiskerData: QueryResultData, outliersData: QueryResultData, dataOptions?: BoxplotChartDataOptionsInternal) => QueryResultData;
/**
 * Processes box whisker data and outliers data to combine them into a single data set.
 *
 * @param boxWhiskerData - The data for the box whisker.
 * @param outliersData - The data for the outliers.
 * @param dataOptions - Optional data options for customizing data processing.
 * @returns The combined data with outliers included in the box whisker plot.
 * @shortDescription Utility function that combines box whisker data and outliers data
 * @group Charts
 */
export declare function boxWhiskerProcessResult(boxWhiskerData: QueryResultData, outliersData: QueryResultData, dataOptions?: BoxplotChartCustomDataOptions): QueryResultData;
export declare const executeBoxplotQuery: ({ app, chartDataOptions, dataSource, attributes, measures, filters, filterRelations, highlights, }: {
    app: ClientApplication;
    chartDataOptions: BoxplotChartDataOptionsInternal;
    dataSource?: DataSource | undefined;
    attributes: Attribute[];
    measures: Measure[];
    filters?: Filter[] | undefined;
    filterRelations?: FilterRelationsJaql | undefined;
    highlights?: Filter[] | undefined;
}, executeQuery: typeof executeQueryFunction) => Promise<QueryResultData>;
