import { RelativeColoringFunction } from '.';
import { RangeDataColorOptions } from '../../types';
/**
 * Returns a relative coloring function based on the provided color options.
 *
 * @param colorOpts - The color options for range coloring.
 * @returns The relative coloring function.
 */
export declare function getRangeColoringFunction(colorOpts: RangeDataColorOptions): RelativeColoringFunction;
/**
 * Retrieves the interpolator function for range coloring.
 *
 * @param minColor - Color of the minimum.
 * @param maxColor - Color of the maximum.
 * @param minValue - The minimum value where minColor should be applied.
 * @param midValue - Value of the gradient center.
 * @param maxValue - The minimum value where maxColor should be applied.
 * @param steps - The number of interpolation steps.
 * @returns The interpolator function.
 */
export declare const getInterpolatorFn: (minColor: string, maxColor: string, minValue: number, midValue: number, maxValue: number, steps?: number) => (value: number) => string;
