import { HighchartsPointerEvent, HighchartsSelectEvent } from '../types';
import { HighchartsOptionsInternal } from '../chart-options-processor/chart-options-service';
import { SisenseChartDataPointEventHandler, SisenseChartDataPointsEventHandler } from '../sisense-chart/types';
import { ChartDataOptionsInternal } from '..';
export type HighchartsEventOptions = {
    chart: {
        zoomType?: string;
        events: {
            selection?: (ev: HighchartsSelectEvent) => void;
        };
    };
    plotOptions: {
        series: {
            point: {
                events: {
                    click?: (ev: HighchartsPointerEvent) => void;
                    contextmenu?: (ev: HighchartsPointerEvent) => void;
                };
            };
        };
    };
};
export declare const applyEventHandlersToChart: (chartOptions: HighchartsOptionsInternal, dataOptions: ChartDataOptionsInternal, { onDataPointClick, onDataPointContextMenu, onDataPointsSelected, }?: {
    onDataPointClick?: SisenseChartDataPointEventHandler | undefined;
    onDataPointContextMenu?: SisenseChartDataPointEventHandler | undefined;
    onDataPointsSelected?: SisenseChartDataPointsEventHandler | undefined;
}) => HighchartsOptionsInternal;
/**
 * Composable variant of applyEventHandlersToChart.
 * Returns a function that applies event handlers to the chart options.
 *
 * @param dataOptions - The data options to use.
 * @param onDataPointClick - The event handler for data point click.
 * @param onDataPointContextMenu - The event handler for data point context menu.
 * @param onDataPointsSelected - The event handler for data points selected.
 * @returns A function that applies event handlers to the chart options.
 */
export declare function withEventHandlers(dataOptions: ChartDataOptionsInternal, { onDataPointClick, onDataPointContextMenu, onDataPointsSelected, }?: {
    onDataPointClick?: SisenseChartDataPointEventHandler;
    onDataPointContextMenu?: SisenseChartDataPointEventHandler;
    onDataPointsSelected?: SisenseChartDataPointsEventHandler;
}): (chartOptions: HighchartsOptionsInternal) => HighchartsOptionsInternal;
