import { Stacking, Style } from '../chart-options-service';
import { ChartDataOptionsInternal, StyledColumn } from '../../chart-data-options/types';
import { ChartType, CompleteThemeSettings } from '../../types';
import { CategoricalXValues } from '../../chart-data/types';
import { AxisClipped } from './translations-to-highcharts';
export type Axis = {
    enabled?: boolean;
    titleEnabled?: boolean;
    title?: string | null;
    gridLine?: boolean;
    labels?: boolean;
    type?: 'linear' | 'logarithmic';
    min?: number | null;
    max?: number | null;
    tickInterval?: number | null;
};
export type AxisMinMax = {
    min: number;
    max: number;
};
export type AxisOrientation = 'horizontal' | 'vertical';
export interface AxisLabelsFormatterContextObject {
    value: string | number;
    axis: {
        categories: (string | number)[];
    };
}
export type AxisSettings = {
    type?: 'linear' | 'logarithmic';
    title?: {
        text?: string | null;
        enabled?: boolean;
        margin?: number;
        style?: Style;
    };
    gridLineDashStyle?: 'Dot';
    gridLineWidth?: number;
    gridLineColor?: string;
    tickWidth?: number;
    lineColor?: string;
    lineWidth?: number;
    labels?: {
        overflow?: 'none' | 'justify';
        enabled?: boolean;
        autoRotation?: number[];
        style?: Style;
        rotation?: number;
        formatter?: (this: AxisLabelsFormatterContextObject) => string;
    };
    min?: number | null;
    max?: number | null;
    minPadding?: number;
    maxPadding?: number;
    tickInterval?: number | null;
    categories?: string[];
    opposite?: boolean;
    plotBands?: AxisPlotBand[];
    plotLines?: AxisPlotLine[];
    tickmarkPlacement?: string;
    minorGridLineWidth?: number;
    minorTickWidth?: number;
    startOnTick?: boolean;
    endOnTick?: boolean;
    tickColor?: string;
    tickLength?: number;
    minorTickColor?: string;
    minorTickLength?: number;
    minorGridLineColor?: string;
    minorGridLineDashStyle?: string;
    stackLabels?: StackLabel;
    showLastLabel?: boolean;
    visible?: boolean;
};
export type StackLabel = {
    style: Style;
    crop: boolean;
    allowOverlap: boolean;
    enabled: boolean;
    rotation: number;
    labelrank: number;
    x?: number;
    y?: number;
};
export type PlotBand = {
    text: string;
    from: number;
    to: number;
};
export type AxisPlotLine = {
    color: string;
    dashStyle: string;
    width: number;
    value: number;
};
export type AxisPlotBand = {
    from: number;
    to: number;
    color?: string;
    label?: {
        text: string;
        x: number;
        y: number;
        style?: Style;
    };
};
export declare const getCategoricalCompareValue: (value: CategoricalXValues) => number;
export declare const getDefaultDateFormat: (granularity?: string) => "HH:mm:ss" | "yyyy" | "yyyy Q" | "MM/yyyy" | "ww yyyy" | "M/d/yy" | "HH" | "M/d/yy HH" | "HH:mm" | undefined;
export declare const getDateFormatter: (category: StyledColumn, dateFormatter?: ((date: Date, format: string) => string) | undefined) => (time: number) => string;
export declare const getXAxisDatetimeSettings: (axis: Axis, category: StyledColumn, values: number[], dateFormatter?: ((date: Date, format: string) => string) | undefined) => AxisSettings[];
export declare const getXAxisSettings: (axis: Axis, axis2: Axis | undefined, categories: string[], plotBands: PlotBand[], xAxisOrientation: AxisOrientation, dataOptions: ChartDataOptionsInternal, chartType: ChartType) => AxisSettings[];
export declare const getYAxisSettings: (axis: Axis, axis2: Axis | undefined, axisMinMax: AxisMinMax, axis2MinMax: AxisMinMax | undefined, showTotal: boolean, totalLabelRotation: number, dataOptions: ChartDataOptionsInternal, stacking: Stacking | undefined, themeSettings?: CompleteThemeSettings) => [AxisSettings[], AxisClipped[]];
