import { PlotOptions } from '../chart-options-service';
import { ValueLabelSettings } from './value-label-section';
import { CompleteThemeSettings } from '../../types';
import { FunnelChartDesignOptions } from './design-options';
import { ChartDataOptionsInternal } from '../../chart-data-options/types';
export declare const DefaultFunnelLabels: FunnelLabels;
export type FunnelLabels = {
    enabled: boolean;
    showCategories: boolean;
    showValue: boolean;
    showPercent: boolean;
    showDecimals: boolean;
};
export declare const DefaultFunnelSize: FunnelSize;
export declare const funnelSizes: readonly ["wide", "regular", "narrow"];
/** Visual size of the lowest slice (degree of funnel narrowing from highest to lowest slices)*/
export type FunnelSize = (typeof funnelSizes)[number];
export declare const DefaultFunnelType: FunnelType;
export declare const funnelTypes: readonly ["regular", "pinched"];
/** Visual type of the lowest slice of Funnel chart */
export type FunnelType = (typeof funnelTypes)[number];
export declare const DefaultFunnelDirection: FunnelDirection;
export declare const funnelDirections: readonly ["regular", "inverted"];
/** Direction of Funnel chart narrowing */
export type FunnelDirection = (typeof funnelDirections)[number];
export type FunnelOptions = {
    allowPointSelect: boolean;
    cursor: 'pointer';
    dataLabels: ValueLabelSettings & {
        funnelMinimumFontSizeToTextLabel: number;
        formatter?: () => string;
    };
    showInLegend: boolean;
    reversed: boolean;
    neckWidth: string | number;
    neckHeight: string | number;
    width: string | number;
};
export declare const isFunnelReversed: (direction: FunnelDirection) => boolean;
export declare const seriesDataLabels: (labels: FunnelLabels) => {
    enabled: boolean;
};
export type RenderTo = {
    clientWidth: number;
    clientHeight: number;
};
export declare const MAX_FUNNEL_WIDTH = 66.6;
export declare const HEIGHT_TO_WIDTH_COEFFICIENT = 1.5;
export declare const DEFAULT_NECK_WIDTH = 15;
export declare const DEFAULT_SHIFT = 50;
export declare const funnelWidthPercentage: (renderTo: RenderTo | null) => number;
export declare const funnelNeckWidth: (widthPercentage: number, funnelSize: FunnelSize) => number;
export declare const funnelNeckHeight: (type: FunnelType) => number;
export declare const getFunnelPlotOptions: (funnelDesignOptions: FunnelChartDesignOptions, chartDataOptions: ChartDataOptionsInternal, themeSettings?: CompleteThemeSettings) => PlotOptions;
