import { IndicatorLegacyChartDataOptions } from '../indicator-legacy-chart-data-options.js';
import { BaseMeasure, FitSecondaryMeasure, FitTitleMeasure, FitValueMeasure, LegacyIndicatorChartOptions } from '../types.js';
export declare class Gauge {
    /**
     * Returns base measure data.
     */
    getBaseMeasure(data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions, container: HTMLElement): BaseMeasure | null;
    /**
     * Renders indicator gauge widget.
     *
     * @param {HTMLElement} canvas
     * @param {object} data
     * @param {object} options
     * @param {object} baseMeasure
     */
    render(canvas: HTMLCanvasElement, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any, baseMeasure: BaseMeasure): void;
    /**
     * Returns fit title measure data.
     *
     * @param ctx
     * @param data
     * @param options
     */
    getFitTitleMeasure(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): FitTitleMeasure;
    /**
     * Returns fit value measure data.
     *
     * @param ctx
     * @param data
     * @param options
     */
    getFitValueMeasure(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): FitValueMeasure;
    /**
     * Returns fit value measure data.
     *
     * @param ctx
     * @param data
     * @param options
     */
    getFitSecondaryMeasure(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): FitSecondaryMeasure;
    /**
     * Returns canvas width.
     *
     * @param data
     * @param options
     */
    getCanvasWidth(data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): number;
    /**
     * Draws indicator numeric bar widget.
     *
     * @param ctx
     * @param data
     * @param options
     */
    draw(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Clears the canvas.
     *
     * @param ctx
     * @param options
     */
    clearCanvas(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the title section.
     *
     * @param ctx
     * @param options
     */
    drawTitle(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the gauge section.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawGauge(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions | any, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the value section.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawValue(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the secondary section.
     *
     * @param ctx
     * @param options
     */
    drawSecondary(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the left and right brackets.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawBrackets(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Returns the gauge needle angle.
     *
     * @param data
     * @param options
     */
    getNeedleAngle(data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): any;
    /**
     * Returns the angle according to the passed value, min and max arguments.
     *
     * @param options
     * @param value
     * @param min
     * @param max
     */
    getAngle(options: LegacyIndicatorChartOptions | any, value: number, min: number, max: number): number;
    /**
     * Draws conditional dial section.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawConditionalDial(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions | any, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws simple dial section.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawSimpleDial(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the gauge arc section.
     *
     * @param ctx
     * @param options
     * @param startAngleRad
     * @param endAngleRad
     * @param color
     */
    drawArc(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any, startAngleRad: number, endAngleRad: number, color: string): void;
    /**
     * Draws the gauge ticks.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawTicks(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the gauge needle.
     *
     * @param {object} ctx
     * @param {object} options
     */
    drawNeedle(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the gauge labels.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawLabels(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
}
