import { IndicatorLegacyChartDataOptions } from '../indicator-legacy-chart-data-options.js';
import { BaseMeasure, FitSecondaryMeasure, FitTitleMeasure, FitValueMeasure, LegacyIndicatorChartOptions } from '../types.js';
export declare class NumericBar {
    /**
     * Returns base measure data.
     *
     * @param {object} data
     * @param {object} options
     * @param {HTMLElement} container
     * @returns {BaseMeasure|null}
     */
    getBaseMeasure(data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions, container: HTMLElement): BaseMeasure | null;
    /**
     * Renders indicator numeric bar widget.
     *
     * @param canvas
     * @param data
     * @param options
     * @param baseMeasure
     */
    render(canvas: HTMLCanvasElement, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any, baseMeasure: BaseMeasure): void;
    /**
     * Returns fit title measure data.
     *
     * @param ctx
     * @param data
     * @param options
     */
    getFitTitleMeasure(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): FitTitleMeasure;
    /**
     * Returns fit value measure data.
     *
     * @param ctx
     * @param data
     * @param options
     */
    getFitValueMeasure(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): FitValueMeasure;
    /**
     * Returns fit value measure data.
     *
     * @param ctx
     * @param data
     * @param options
     */
    getFitSecondaryMeasure(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): FitSecondaryMeasure;
    /**
     * Returns canvas width.
     *
     * @param data
     * @param options
     */
    getCanvasWidth(data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): number;
    /**
     * Draws indicator numeric bar widget.
     *
     * @param ctx
     * @param data
     * @param options
     */
    draw(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Clears the canvas.
     *
     * @param ctx
     * @param options
     */
    clearCanvas(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the title section.
     *
     * @param ctx
     * @param options
     */
    drawTitle(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the value section.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawValue(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the secondary section.
     *
     * @param ctx
     * @param options
     */
    drawSecondary(ctx: CanvasRenderingContext2D, options: LegacyIndicatorChartOptions | any): void;
    /**
     * Draws the left and right brackets.
     *
     * @param ctx
     * @param data
     * @param options
     */
    drawBrackets(ctx: CanvasRenderingContext2D, data: IndicatorLegacyChartDataOptions, options: LegacyIndicatorChartOptions | any): void;
}
