import { CustomWidgetComponent } from './types';
/**
 * Hook that provides API for configuring custom widgets.
 *
 * @example
 * Example of registering a custom widget in a dashboard:
 * ```tsx
 * import { useCustomWidgets, DashboardById } from '@sisense/sdk-ui';
 * import CustomHistogramWidget from './custom-histogram-widget';
 *
 * const Example = () => {
 *   const { registerCustomWidget } = useCustomWidgets();
 *   registerCustomWidget('histogramwidget', CustomHistogramWidget);
 *
 *   return <DashboardById dashboardOid="your-dashboard-oid" />;
 * }
 * ```
 *
 * @group Dashboards
 */
export declare const useCustomWidgets: () => {
    registerCustomWidget: <T = any>(customWidgetType: string, customWidget: CustomWidgetComponent<T>) => void;
    hasCustomWidget: (customWidgetType: string) => boolean;
    getCustomWidget: (customWidgetType: string) => CustomWidgetComponent<any> | undefined;
};
