import { Attribute, Measure } from '@sisense/sdk-data';
import { GenericDataOptions } from '../types';
import { CustomWidgetComponentProps } from './types';
import { ExecuteQueryParams, QueryState } from '../query-execution/types';
import { HookEnableParam } from '../common/hooks/types';
/**
 * State of a query execution retrieving data of a custom widget.
 */
export type CustomWidgetQueryState = QueryState;
/**
 * Parameters for executing a query for a custom widget.
 */
export interface ExecuteCustomWidgetQueryParams extends CustomWidgetComponentProps, HookEnableParam, Pick<ExecuteQueryParams, 'onBeforeQuery' | 'count' | 'offset' | 'ungroup'> {
}
/**
 * Utility function for converting data options to parameters for executing a query.
 *
 * @group Dashboards
 */
export declare function extractDimensionsAndMeasures(dataOptions: GenericDataOptions): {
    dimensions: Attribute[];
    measures: Measure[];
};
/**
 * {@link useExecuteCustomWidgetQuery} without tracking to be used inside other hooks or components in Compose SDK.
 *
 * @internal
 */
export declare function useExecuteCustomWidgetQueryInternal({ dataSource, dataOptions, filters, highlights, count, offset, ungroup, onBeforeQuery, }: ExecuteCustomWidgetQueryParams): CustomWidgetQueryState;
/**
 * React hook that takes a custom widget component's props and executes a data query.
 *
 * @group Queries
 */
export declare const useExecuteCustomWidgetQuery: (args_0: ExecuteCustomWidgetQueryParams) => QueryState;
