import { WidgetsPanelLayout } from '../../../models';
import { WidgetProps } from '../../../props';
/**
 * Props for the {@link EditableLayout} component.
 *
 * @internal
 */
export interface EditableLayoutProps {
    /**
     * An object defining how the widgets should be laid out.
     */
    layout: WidgetsPanelLayout;
    /**
     * A list of widget props to render.
     */
    widgets: WidgetProps[];
    /**
     * A callback function that is called when the layout changes.
     */
    onLayoutChange?: (layout: WidgetsPanelLayout) => void;
    /**
     * The configuration for the editable layout.
     */
    config?: {
        /**
         * Flag indicating whether the drag handle icon is visible.
         *
         * @default true
         */
        showDragHandleIcon?: boolean;
    };
}
/**
 * A React used to render a layout of widgets that can resize and rearrange their positions using drag-and-drop.
 *
 * @param props - {@link EditableLayoutProps}
 * @internal
 */
export declare const EditableLayout: ({ layout, widgets, onLayoutChange, config, }: EditableLayoutProps) => import("react/jsx-runtime").JSX.Element;
