/// <reference types="react" />
import { DashboardProps } from '../dashboard/types';
import { Filter, FilterRelations } from '@sisense/sdk-data';
import { WidgetsPanelLayout } from '../models';
export declare enum DashboardChangeType {
    /** Dashboard filters have been updated */
    FILTERS_UPDATE = "FILTERS.UPDATE",
    /** Filters panel collapsed state changed */
    UI_FILTERS_PANEL_COLLAPSE = "UI.FILTERS.PANEL.COLLAPSE",
    /** Widgets panel layout updated */
    WIDGETS_PANEL_LAYOUT_UPDATE = "WIDGETS_PANEL_LAYOUT.UPDATE",
    /** Edit mode isEditing changed */
    WIDGETS_PANEL_LAYOUT_IS_EDITING_CHANGE = "WIDGETS_PANEL.EDIT_MODE.IS_EDITING.CHANGE",
    /** Widgets deleted from the dashboard */
    WIDGETS_DELETE = "WIDGETS.DELETE"
}
export type DashboardChangeAction = {
    type: DashboardChangeType.FILTERS_UPDATE;
    payload: Filter[] | FilterRelations;
} | {
    type: DashboardChangeType.UI_FILTERS_PANEL_COLLAPSE;
    payload: boolean;
} | {
    type: DashboardChangeType.WIDGETS_PANEL_LAYOUT_UPDATE;
    payload: WidgetsPanelLayout;
} | {
    type: DashboardChangeType.WIDGETS_PANEL_LAYOUT_IS_EDITING_CHANGE;
    payload: boolean;
} | {
    type: DashboardChangeType.WIDGETS_DELETE;
    payload: string[];
};
/**
 * React component that renders a dashboard whose elements are customizable. It includes internal logic of applying common filters to widgets.
 *
 * **Note:** Dashboard and Widget extensions based on JS scripts and add-ons in Fusion – for example, Blox and Jump To Dashboard – are not supported.
 *
 * @example
 *
 * Example of rendering a Fusion dashboard using the `useGetDashboardModel hook and the `Dashboard` component.
 *
 * ```ts
 * import { Dashboard, useGetDashboardModel, dashboardModelTranslator } from '@sisense/sdk-ui';

const CodeExample = () => {
  const { dashboard } = useGetDashboardModel({
    dashboardOid: '65a82171719e7f004018691c',
    includeFilters: true,
    includeWidgets: true,
  });

  return (
    <>
      {dashboard && (
        <Dashboard {...dashboardModelTranslator.toDashboardProps(dashboard)} />
      )}
    </>
  );
};

export default CodeExample;
 * ```
 *
 * To learn more about this and related dashboard components,
 * see [Embedded Dashboards](/guides/sdk/guides/dashboards/index.html).
 * @group Dashboards
 */
export declare const Dashboard: import("react").FunctionComponent<DashboardProps>;
