import { DashboardProps } from './types.js';
import { Filter, FilterRelations } from '@sisense/sdk-data';
import { WidgetsPanelLayout } from '../models';
export type ComposableDashboardProps = Pick<DashboardProps, 'filters' | 'widgets' | 'widgetsOptions' | 'layoutOptions' | 'tabbersOptions'>;
export type UseComposedDashboardOptions = {
    /**
     * @internal
     */
    onFiltersChange?: (filters: Filter[] | FilterRelations) => void;
};
/**
 * {@link useComposedDashboard} without tracking to be used inside other hooks or components in Compose SDK.
 *
 * @param params - Parameters of the composable dashboard props
 * @internal
 */
export declare function useComposedDashboardInternal<D extends ComposableDashboardProps | DashboardProps>(initialDashboard: D, { onFiltersChange }?: UseComposedDashboardOptions): {
    dashboard: D;
    setFilters: (filters: Filter[] | FilterRelations) => void;
    setWidgetsLayout: (newLayout: WidgetsPanelLayout) => void;
};
/**
 * React hook that takes in separate dashboard elements and
 * composes them into a coordinated dashboard with change detection, cross filtering, and drill down.
 *
 * @group Dashboards
 */
export declare const useComposedDashboard: <D extends DashboardProps | ComposableDashboardProps>(args_0: D, args_1?: UseComposedDashboardOptions | undefined) => {
    dashboard: D;
    setFilters: (filters: Filter[] | FilterRelations) => void;
    setWidgetsLayout: (newLayout: WidgetsPanelLayout) => void;
};
