import { DateFilterRange } from '../types';
export type { DateFilterRange };
/**
 * Props for {@link DateFilter}
 *
 * @internal
 */
export type DateRangeFilterProps = {
    /**
     * Callback function that is called when the date range is changed.
     *
     * @param filter - Date range filter
     */
    onChange: (filter: DateFilterRange) => void;
    /**
     * Selected date range.
     */
    value: DateFilterRange['filter'];
    /**
     * Limit of the date range that can be selected.
     */
    limit?: {
        maxDate: string;
        minDate: string;
    };
    /**
     * Whether this is a dependent filter.
     */
    isDependent?: boolean;
    /**
     * The variant of the date range field button.
     * To be compatible with the old DateRangeFilterTile.
     *
     * TODO: Remove this prop when the old DateRangeFilterTile is deprecated.
     *
     * @internal
     * @default 'grey'
     */
    variant?: 'white' | 'grey';
    /**
     * Whether the filter is disabled.
     *
     * @internal
     */
    disabled?: boolean;
};
/**
 * Date Filter component for filtering data by date range.
 *
 * @example
 * React example of configuring the limit date range as well as the selected date range.
 * ```tsx
 * const [{ filter }, setDateRangeFilter] = useState<DateFilterRange>({
 *   type: 'date-range',
 *   filter: {
 *     from: '2019-06-08',
 *     to: '2019-06-16',
 *   },
 * });
 *
 * return (
 *   <DateFilter
 *     onChange={(dateFilter) => {
 *       setDateRangeFilter(dateFilter);
 *     }}
 *     limit={{
 *       minDate: '2019-06-05',
 *       maxDate: '2019-06-25',
 *     }}
 *     value={{ from: filter.from, to: filter.to }}
 *   />
 * );
 * ```
 *
 * <img src="media://date-filter-example-1.png" width="800px" />
 * @param props - Date Filter Props
 * @returns Date Filter component
 * @internal
 */
export declare function DateFilter(props: DateRangeFilterProps): import("react/jsx-runtime").JSX.Element;
