/// <reference types="react" />
import { Filter } from '@sisense/sdk-data';
import { FilterVariant } from '../../common/index.js';
import { FilterTileDesignOptions } from '../../filter-tile-container.js';
/**
 * Props of the {@link RelativeDateFilterTile} component.
 */
export interface RelativeDateFilterTileProps {
    /**Filter tile title */
    title: string;
    /** Relative date filter. */
    filter: Filter;
    /** Arrangement of the filter inputs. Use vertical for standard filter tiles and horizontal for toolbars */
    arrangement?: FilterVariant;
    /**
     * Callback function that is called when the relative date filter object should be updated.
     *
     * @param filter - Relative date filter
     */
    onUpdate: (filter: Filter) => void;
    /** Filter delete callback */
    onDelete?: () => void;
    /** Filter edit callback */
    onEdit?: () => void;
    /**
     * Limit of the date range that can be selected.
     */
    limit?: {
        maxDate: string;
        minDate: string;
    };
    /**
     * Design options for the filter tile component
     *
     * @internal
     */
    tileDesignOptions?: FilterTileDesignOptions;
}
/**
 * UI component that allows the user to filter date attributes according to
 * a number of built-in operations defined in the relative date filter.
 * Useful for filtering data by relative date ranges, such as "last 7 days" or "next 30 days from Date".
 *
 * @param props - Relative date filter tile props
 * @returns Relative date filter tile component
 * @group Filter Tiles
 */
export declare const RelativeDateFilterTile: import("react").FunctionComponent<RelativeDateFilterTileProps>;
