import { FunctionComponent } from 'react';
import { Member, SelectedMember } from './members-reducer';
/**
 * Props for {@link BasicMemberFilterTile}
 *
 * @internal
 */
export interface BasicMemberFilterTileProps {
    /** Title to display in the header */
    title: string;
    /** All selectable members */
    allMembers: Member[];
    /** Initial list of selected members. Defaults to empty list */
    initialSelectedMembers?: SelectedMember[];
    /** Callback that executes whenever the final list of active and selected members is updated */
    onUpdateSelectedMembers?: (members: string[], disabled?: boolean) => void;
    /** Configurable limit on size of allowedMembers */
    maxAllowedMembers?: number;
    /** Whether this is a dependent filter */
    isDependent?: boolean;
    /** Flag to update selected members when caused by an external change */
    shouldUpdateSelectedMembers?: boolean;
    /** Whether the filter tile is disabled initially */
    disabled?: boolean;
}
/**
 * UI component that, given a list of members to select from and a list of
 * initial selections, can render selected members as "pills" and can also show
 * a searchable list of members to choose from.
 *
 * @example
 *
 * The example below constructs a BasicMemberFilterTile with a list of all members and a list of initially selected members.
 *
 *
 * ```tsx
 *   const allMembers = ['United States', 'Canada', 'Mexico'].map((m) => ({ key: m, title: m }));
 *   const selectedMembers = ['United States', 'Mexico'].map((m) => ({ key: m, title: m }));
 *
 *   return (
 *     <div>
 *       <BasicMemberFilterTile
 *         title={'Country'}
 *         allMembers={allMembers}
 *         initialSelectedMembers={selectedMembers}
 *       />
 *     </div>
 *   );
 * ```
 *
 * <img src="media://basic-member-filter-tile-example-1.png" width="300px" />
 * @param props - Basic member filter tile props
 * @returns Basic member filter tile component
 * @internal
 */
export declare const BasicMemberFilterTile: FunctionComponent<BasicMemberFilterTileProps>;
