import { HttpClient } from '@sisense/sdk-rest-client';
import { DashboardModel } from '../../models/dashboard';
import { CompleteThemeSettings } from '../../types';
import { AppSettings } from '../../app/settings/settings';
export interface GetDashboardModelOptions {
    /**
     * Boolean flag whether to include widgets in the dashboard model
     *
     * If not specified, the default value is `false`
     */
    includeWidgets?: boolean;
    /**
     * Boolean flag whether to include filters in the dashboard model
     *
     * If not specified, the default value is `false`
     */
    includeFilters?: boolean;
    /**
     * Whether to load the dashboard in shared mode (co-authoring feature).
     *
     * @default false
     * @internal
     */
    sharedMode?: boolean;
}
/**
 * Retrieves a dashboard model by its OID.
 *
 * @param http - The HTTP client
 * @param dashboardOid - The OID of the dashboard
 * @param options - The options to include widgets and filters in the dashboard model
 * @param themeSettings - Optional theme settings
 * @param appSettings - Optional application settings
 * @returns The dashboard model
 * @internal
 */
export declare function getDashboardModel(http: HttpClient, dashboardOid: string, options?: GetDashboardModelOptions, themeSettings?: CompleteThemeSettings, appSettings?: AppSettings): Promise<DashboardModel>;
