import { DashboardModel, WidgetModel, WidgetsPanelLayout } from '../../../models';
import { Filter, FilterRelations } from '@sisense/sdk-data';
import { RestApi } from '../../../api/rest-api';
export type UseDashboardModelState = DashboardModel | null;
/**
 * Internal action types for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export declare enum UseDashboardModelActionTypeInternal {
    DASHBOARD_INIT = "DASHBOARD.INIT",
    UPDATE_WIDGETS_PANEL_LAYOUT_AND_WIDGETS_DELETE = "UPDATE_WIDGETS_PANEL_LAYOUT_AND_WIDGETS_DELETE"
}
/**
 * Action types for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export declare enum UseDashboardModelActionType {
    FILTERS_UPDATE = "FILTERS.UPDATE",
    ADD_WIDGET = "WIDGETS.ADD",
    WIDGETS_PANEL_LAYOUT_UPDATE = "WIDGETS_PANEL_LAYOUT.UPDATE",
    WIDGETS_DELETE = "WIDGETS.DELETE"
}
/**
 * Internal actions for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export type UseDashboardModelInternalAction = UseDashboardModelAction | {
    type: UseDashboardModelActionTypeInternal.DASHBOARD_INIT;
    payload: DashboardModel;
} | {
    type: UseDashboardModelActionTypeInternal.UPDATE_WIDGETS_PANEL_LAYOUT_AND_WIDGETS_DELETE;
    payload: {
        widgetsPanel: WidgetsPanelLayout;
        widgets: string[];
    };
};
/**
 * Actions for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export type UseDashboardModelAction = UseDashboardModelFilterUpdateAction | UseDashboardModelAddWidgetAction | UseDashboardModelLayoutUpdateAction | UseDashboardWidgetsDeleteAction;
/**
 * Filter update actions for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export type UseDashboardModelFilterUpdateAction = {
    type: UseDashboardModelActionType.FILTERS_UPDATE;
    payload: Filter[] | FilterRelations;
};
/**
 * Add widget action for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export type UseDashboardModelAddWidgetAction = {
    type: UseDashboardModelActionType.ADD_WIDGET;
    payload: WidgetModel;
};
/**
 * Layout update action for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export type UseDashboardModelLayoutUpdateAction = {
    type: UseDashboardModelActionType.WIDGETS_PANEL_LAYOUT_UPDATE;
    payload: WidgetsPanelLayout;
};
/**
 * Layout update action for the dashboard model state used in {@link useDashboardModel}.
 *
 * @internal
 */
export type UseDashboardWidgetsDeleteAction = {
    type: UseDashboardModelActionType.WIDGETS_DELETE;
    payload: string[];
};
/**
 * Reducer for the dashboard model state used in {@link useDashboardModel}.
 *
 * @param state
 * @param action
 * @internal
 */
export declare function dashboardReducer(state: UseDashboardModelState, action: UseDashboardModelInternalAction): UseDashboardModelState;
/**
 * Translates filters and relations to DTOs.
 *
 * @param filtersOrFilterRelations - The filters or filter relations to translate
 * @returns The translated filters and relations DTOs for Fusion
 * @internal
 */
export declare function translateFiltersAndRelationsToDto(filtersOrFilterRelations: Filter[] | FilterRelations): {
    filters: (import("../../../api/types/dashboard-dto").FilterDto | import("../../../api/types/dashboard-dto").CascadingFilterDto)[];
    filterRelations: {
        datasource: string;
        filterRelations: import("@sisense/sdk-data").FilterRelationsModelNode;
    }[] | undefined;
};
/**
 * Middleware that persists the dashboard model changes to the Sisense server.
 *
 * @param restApi - The Sisense REST API instance
 * @param reducer - The dashboard model reducer
 * @internal
 */
export declare function persistDashboardModelMiddleware(dashboardOid: string | undefined, action: UseDashboardModelInternalAction, restApi: RestApi, sharedMode: boolean): Promise<UseDashboardModelInternalAction>;
