import { ExecutePivotQueryParams, PivotQueryState } from './types';
/**
 * React hook that executes a data query for a pivot table.
 * This approach is similar to React Query's `useQuery` hook.
 *
 * ## Example
 *
 * Execute a pivot query on the Sample ECommerce data model and display the results in a table.
 *
 * <iframe
 *  src='https://csdk-playground.sisense.com/?example=queries%2Fuse-execute-pivot-query&mode=docs'
 *  width=800
 *  height=870
 *  style='border:none;'
 * />
 *
 * @returns Query state that contains the status of the query execution, the result data, or the error if any occurred
 * @group Queries
 * @beta
 */
export declare const useExecutePivotQuery: (params: ExecutePivotQueryParams) => PivotQueryState;
/**
 * {@link useExecutePivotQuery} without tracking to be used inside other hooks or components in Compose SDK.
 *
 * @param params - Parameters of the query
 * @internal
 */
export declare function useExecutePivotQueryInternal(params: ExecutePivotQueryParams): PivotQueryState;
/**
 * Checks if the query parameters have changed by deep comparison.
 *
 * @param params - New query parameters
 */
export declare function usePivotQueryParamsChanged(params: ExecutePivotQueryParams): boolean;
