import Color from 'colorjs.io';
export declare const TRIANGLE_COLOR_ADJUSTMENT = 0.15;
export type ColorArg = string | Color;
export declare const toColor: (color: ColorArg) => Color;
export declare const toString: (color: Color) => string;
export declare const toRangeFn: (...colorArgs: ColorArg[]) => (percentage: number) => string;
export declare const toSteps: (numSteps: number, ...colorArgs: ColorArg[]) => string[];
export declare const toGray: (color: ColorArg) => string;
export declare const toAvg: (color1: ColorArg, color2: ColorArg) => string;
export declare const hueDiff: (color1: ColorArg, color2: ColorArg) => number;
/**
 * Scales the color's brightness by the given percentage.
 *
 * @param colorArg - The color to scale, in any valid color format (e.g., hex, RGB, HSL).
 * @param percent - The percentage by which to scale the color's brightness.
 *                 A positive value will increase the brightness, while a negative value will decrease it.
 *                 The percentage should be a number between -1 and 1, where -1 represents a 100% decrease
 *                 in brightness (i.e., completely black) and 1 represents a 100% increase in brightness
 *                 (i.e., completely white).
 * @returns The scaled color as a string.
 */
export declare const scaleBrightness: (colorArg: ColorArg, percent: number) => string;
export declare const getRgbValuesFromColor: (color: Color) => {
    R: number;
    G: number;
    B: number;
};
export declare const getDarkFactor: (color: Color) => number;
export declare function isBright(color: Color): boolean;
export declare const getSlightlyDifferentColor: (colorString: string, percent?: number, opacity?: number) => string;
/**
 * Applies opacity to a color
 *
 * @param color - color to apply opacity to
 * @param opacity - opacity to apply (from 0 to 1)
 * @returns - color with opacity applied
 */
export declare const applyOpacity: (color: string, opacity: number) => string;
/**
 * Give an array of color steps in provided range
 *
 * @param minColor - start range color
 * @param maxColor - end range color
 * @param steps - count of color steps
 * @returns - array with color steps
 */
export declare const getExplicitColorSteps: (minColor: string, maxColor: string, steps: number) => string[];
