/**
 * Overrides the default options with custom settings based on a mapping dictionary.
 *
 * @param customSettings - The custom settings to apply.
 * @param defaultOptionsToCustomSettingsDictionary - The dictionary mapping default options to custom settings keys.
 * @param defaultOptions - The default options to override.
 * @returns The overridden options object.
 * @example
  const customSettings = { a: { b: { c: 'custom_cc' } } };
  const defaultOptions = { aa: { bb: { cc: 'cc' } }, cc: 'cc' };
  const customSettingsToDefaultOptionsDictionary = {
    'aa.bb.cc': 'a.b.c',
    cc: 'a.b.c',
  };
  const overriddenOptions = overrideWithCustomSettings(
      customSettings,
      customSettingsToDefaultOptionsDictionary,
      defaultOptions,
    );
  // overriddenOptions = { aa: { bb: { cc: 'custom_cc' } }, cc: 'custom_cc' };
 */
export declare function overrideWithCustomSettings<DefaultOptions extends Record<string, any>>(customSettings: Record<string, any>, defaultOptionsToCustomSettingsDictionary: Record<string, string>, defaultOptions: DefaultOptions): DefaultOptions;
