import { ChartSubtype } from '../chart-options-processor/subtype-to-design-options.js';
import { ChartType, RenderToolbarHandler } from '../types.js';
import { Panel, PanelItem, TextWidgetDtoStyle, WidgetStyle, WidgetSubtype, FusionWidgetType } from './types.js';
import { ChartProps, ChartWidgetProps, PivotTableWidgetProps, CustomWidgetProps, TextWidgetProps, CommonWidgetProps, WithCommonWidgetProps, WidgetProps, WidgetType } from '../props';
import { WidgetTypeInternal } from '../models/widget/types';
import { WidgetModel } from '../models';
export { mergeFilters, getFilterRelationsFromJaql, convertFilterRelationsModelToJaql, getFilterCompareId, } from '@sisense/sdk-data';
/**
 * Returns the corresponding chart type for a given widget type
 *
 * @internal
 */
export declare function getChartType(fusionWidgetType: FusionWidgetType): ChartType;
export declare function getFusionWidgetTypeFromChartType(chartType: ChartType): FusionWidgetType;
export declare function getFusionWidgetType(widgetType: WidgetType, chartType?: ChartType): FusionWidgetType;
export declare function getWidgetType(fusionWidgetType: FusionWidgetType): WidgetType;
export declare function getChartSubtype(widgetSubtype: WidgetSubtype): ChartSubtype | undefined;
export declare function isSupportedWidgetType(fusionWidgetType: FusionWidgetType): fusionWidgetType is FusionWidgetType;
export declare function isTableFusionWidget(fusionWidgetType: FusionWidgetType): boolean;
export declare function isTableWidgetModel(widgetModel: WidgetModel): boolean;
export declare function isPivotTableFusionWidget(fusionWidgetType: FusionWidgetType): boolean;
export declare function isPivotWidget(widgetType: WidgetType): boolean;
export declare function isTextFusionWidget(fusionWidgetType: FusionWidgetType): boolean;
export declare function isTextWidget(widgetType: WidgetType): boolean;
export declare function isTextWidgetDtoStyle(widgetStyle: WidgetStyle): widgetStyle is TextWidgetDtoStyle;
export declare function isCustomWidgetFusionWidget(fusionWidgetType: FusionWidgetType): boolean;
export declare function isCustomWidget(widgetType: WidgetType): boolean;
export declare function isChartFusionWidget(fusionWidgetType: FusionWidgetType): boolean;
export declare function isChartWidget(widgetType: WidgetType): boolean;
/**
 * Type guard for checking if the widget props is for a text widget.
 *
 * @param widgetProps - The widget props to check.
 * @returns whether the widget props is for a text widget
 * @internal
 */
export declare function isTextWidgetProps(widgetProps: CommonWidgetProps): widgetProps is WithCommonWidgetProps<TextWidgetProps, 'text'>;
/**
 * Type guard for checking if the widget props is for a pivot table widget.
 *
 * @param widgetProps - The widget props to check.
 * @returns whether the widget props is for a pivot table widget
 * @internal
 */
export declare function isPivotTableWidgetProps(widgetProps: CommonWidgetProps): widgetProps is WithCommonWidgetProps<PivotTableWidgetProps, 'pivot'>;
/**
 * Type guard for checking if the widget props is for a custom widget
 *
 * @param widgetProps - The widget props to check.
 * @returns whether the widget props is for a custom widget
 * @internal
 */
export declare function isCustomWidgetProps(widgetProps: CommonWidgetProps): widgetProps is WithCommonWidgetProps<CustomWidgetProps, 'custom'>;
/**
 * Type guard for checking if the widget props is for a chart widget
 *
 * @param widgetProps - The widget props to check.
 * @returns whether the widget props is for a chart widget
 * @internal
 */
export declare function isChartWidgetProps(widgetProps: CommonWidgetProps): widgetProps is WithCommonWidgetProps<ChartWidgetProps, 'chart'>;
export declare function getInternalWidgetType(widgetProps: CommonWidgetProps): WidgetTypeInternal;
/**
 * Registers new "onDataPointClick" handler for the Widget component
 *
 * @internal
 */
export declare function registerDataPointClickHandler(widgetProps: WidgetProps, handler: NonNullable<ChartProps['onDataPointClick']>): void;
/**
 * Registers new "onDataPointContextMenu" handler for the Widget component
 *
 * @internal
 */
export declare function registerDataPointContextMenuHandler(widgetProps: WidgetProps, handler: NonNullable<ChartProps['onDataPointContextMenu']>): void;
/**
 * Registers new "onDataPointsSelected" handler for the Widget component
 *
 * @internal
 */
export declare function registerDataPointsSelectedHandler(widgetProps: WidgetProps, handler: NonNullable<ChartProps['onDataPointsSelected']>): void;
/**
 * Registers new "renderToolbar" handler for the constructed component
 *
 * @internal
 */
export declare function registerRenderToolbarHandler(widgetProps: WidgetProps, handler: RenderToolbarHandler): void;
export declare function getEnabledPanelItems(panels: Panel[], panelName: string): PanelItem[];
export declare function getRootPanelItem(item: PanelItem): PanelItem;
