import { DashboardDto, FilterDto, CascadingFilterDto } from '../api/types/dashboard-dto.js';
import { FiltersIgnoringRules, WidgetDto } from './types.js';
import { IncludeAllFilterJaql } from '@sisense/sdk-data';
/**
 * Extracts and merges dashboard and widget filters. This consolidates all
 * filters applicable for a widget.
 *
 * @param dashboard - The dashboard containing the filters.
 * @param widget - The widget containing the filters.
 * @returns An object containing an array of filters and an array of highlights.
 * @internal
 */
export declare function extractCombinedFilters(dashboard: DashboardDto, widget: WidgetDto): {
    filters: import("@sisense/sdk-data").Filter[];
    highlights: import("@sisense/sdk-data").Filter[];
};
/**
 * Extracts dashboard filters applicable to a widget.
 *
 * @param {DashboardDto} dashboard - The dashboard containing the filters.
 * @param {WidgetDto} widget - The widget to extract filters from.
 * @returns {object} An object containing an array of filters and an array of highlights.
 */
export declare function extractDashboardFiltersForWidget(dashboard: DashboardDto, widget: WidgetDto): {
    filters: import("@sisense/sdk-data").Filter[];
    highlights: import("@sisense/sdk-data").Filter[];
};
/**
 * Retrieves the dashboard filters with optional exclusion rules.
 *
 * @param dashboardFilters - The array of dashboard filters
 * @param filtersIgnoringRules - Optional rules for excluding filters.
 * @returns An array of filtered dashboard filters.
 */
export declare function getDashboardFilters(dashboardFilters: Array<FilterDto | CascadingFilterDto>, filtersIgnoringRules?: FiltersIgnoringRules): {
    instanceid: string | undefined;
    jaql: {
        filter: {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            all: true;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            members: string[];
            multiSelection?: boolean | undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            exclude: {
                members: string[];
            };
            multiSelection?: boolean | undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            equals?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            doesntEqual?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            toNotEqual?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            to?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            fromNotEqual?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            from?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            '='?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            '<'?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            '>'?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            '>='?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
            '<='?: (number | import("@sisense/sdk-data").FormulaJaql) | undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            endsWith: string;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            startsWith: string;
            endsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            top: number;
            endsWith?: undefined;
            startsWith?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            bottom: number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            contains: string;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            or: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql[];
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            and: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql[];
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            from: number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            to: number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            last: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").PeriodFilterDetails;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            next: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").PeriodFilterDetails;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            exclude: {
                members?: string[] | undefined;
                from?: number | undefined;
                to?: number | undefined;
            };
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            equals: string | number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            doesntEqual: string | number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            toNotEqual: number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            fromNotEqual: number;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            doesntStartWith: string;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntEndWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            doesntEndWith: string;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntContain?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            by?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").RankingFilterJaql | undefined;
            custom?: boolean | undefined;
            filterType?: import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").FilterType | undefined;
            members?: string[] | undefined;
            multiSelection?: boolean | undefined;
            isNotCurrentPeriod?: boolean | undefined;
            isAdvanced?: boolean | undefined;
            rankingMessage?: string | undefined;
            isBetween?: boolean | undefined;
            isEmpty?: boolean | undefined;
            explicit?: boolean | undefined;
            isCondition?: boolean | undefined;
            doesntContain: string;
            endsWith?: undefined;
            startsWith?: undefined;
            top?: undefined;
            bottom?: undefined;
            contains?: undefined;
            or?: undefined;
            and?: undefined;
            from?: undefined;
            to?: undefined;
            last?: undefined;
            next?: undefined;
            exclude?: undefined;
            equals?: undefined;
            doesntEqual?: undefined;
            toNotEqual?: undefined;
            fromNotEqual?: undefined;
            doesntStartWith?: undefined;
            doesntEndWith?: undefined;
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
        } | {
            filter?: import("@sisense/sdk-data").TurnOffMembersFilterJaql | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & IncludeAllFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").IncludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").ExcludeMembersFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").NumericFilterJaql & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "endsWith">> & Partial<Record<"startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "startsWith">> & Partial<Record<"endsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "top">> & Partial<Record<"endsWith" | "startsWith" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "bottom">> & Partial<Record<"endsWith" | "startsWith" | "top" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "contains">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "from">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "to">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "last">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "next">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "exclude">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "equals">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "toNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "fromNotEqual">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "doesntStartWith" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntStartWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntEndWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntEndWith">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntContain", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "filter" | "by" | "custom" | "filterType" | "members" | "multiSelection" | "isNotCurrentPeriod" | "isAdvanced" | "rankingMessage" | "isBetween" | "isEmpty" | "explicit" | "isCondition"> & Required<Pick<import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaqlOptions, "doesntContain">> & Partial<Record<"endsWith" | "startsWith" | "top" | "bottom" | "contains" | "or" | "and" | "from" | "to" | "last" | "next" | "exclude" | "equals" | "doesntEqual" | "toNotEqual" | "fromNotEqual" | "doesntStartWith" | "doesntEndWith", undefined>> & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & {
                and: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
            } & {
                level?: "string" | undefined;
            }) | ({
                turnedOff?: boolean | undefined;
                exclude?: {
                    members?: string[] | undefined;
                } | undefined;
            } & import("@sisense/sdk-data").OrFilterJaql<import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql> & {
                level?: "string" | undefined;
            }) | undefined;
            or: (import("@sisense/sdk-data").NumericFilterJaql | import("@sisense/sdk-data/dist/dimensional-model/filters/utils/types.js").ConditionFilterJaql)[];
        };
        agg?: string | undefined;
        datatype: "numeric" | "text" | "datetime";
        dim: string;
        table: string;
        column: string;
        datasource?: import("@sisense/sdk-data").JaqlDataSource | undefined;
        title: string;
        level?: "years" | "quarters" | "months" | "weeks" | "minutes" | "days" | undefined;
        sort?: "desc" | "asc" | undefined;
        in?: {
            selected?: {
                jaql: import("@sisense/sdk-data").FilterJaql;
            } | undefined;
        } | undefined;
        merged?: boolean | undefined;
        panel?: "rows" | "columns" | undefined;
    };
}[];
/**
 * Retrieves the dashboard background filters.
 *
 * @param dashboardFilters - The array of dashboard filters
 * @returns An array of background filters from the dashboard.
 */
export declare function getDashboardBackgroundFilters(dashboardFilters: Array<FilterDto | CascadingFilterDto>): FilterDto[];
